@@ -110,6 +110,15 @@ class Cluster(base.APIBase):
     docker_volume_size = wtypes.IntegerType(minimum=1)
     """The size in GB of the docker volume"""
 
+    labels = wtypes.DictType(str, str)
+    """One or more key/value pairs"""
+
+    master_flavor_id = wtypes.StringType(min_length=1, max_length=255)
+    """The flavor of the master node for this Cluster"""
+
+    flavor_id = wtypes.StringType(min_length=1, max_length=255)
+    """The flavor of this Cluster"""
+
     create_timeout = wsme.wsattr(wtypes.IntegerType(minimum=0), default=60)
     """Timeout for creating the cluster in minutes. Default to 60 if not set"""
 
@@ -138,6 +147,12 @@ class Cluster(base.APIBase):
     container_version = wsme.wsattr(wtypes.text, readonly=True)
     """Version of the container software. Example: docker version."""
 
+    project_id = wsme.wsattr(wtypes.text, readonly=True)
+    """Project id of the cluster belongs to"""
+
+    user_id = wsme.wsattr(wtypes.text, readonly=True)
+    """User id of the cluster belongs to"""
+
     node_addresses = wsme.wsattr([wtypes.text], readonly=True)
     """IP addresses of cluster slave nodes"""
 
@@ -162,7 +177,8 @@ class Cluster(base.APIBase):
         if not expand:
             cluster.unset_fields_except(['uuid', 'name', 'cluster_template_id',
                                          'keypair', 'docker_volume_size',
-                                         'node_count', 'status',
+                                         'labels', 'node_count', 'status',
+                                         'master_flavor_id', 'flavor_id',
                                          'create_timeout', 'master_count',
                                          'stack_id'])
 
@@ -188,6 +204,9 @@ class Cluster(base.APIBase):
                      node_count=2,
                      master_count=1,
                      docker_volume_size=1,
+                     labels={},
+                     master_flavor_id='m1.small',
+                     flavor_id='m1.small',
                      create_timeout=15,
                      stack_id='49dc23f5-ffc9-40c3-9d34-7be7f9e34d63',
                      status=fields.ClusterStatus.CREATE_COMPLETE,
@@ -259,6 +278,23 @@ class ClustersController(base.Controller):
                                  sort_key, sort_dir, expand=False,
                                  resource_url=None):
 
+        context = pecan.request.context
+        if context.is_admin:
+            if expand:
+                policy.enforce(context, "cluster:detail_all_projects",
+                               action="cluster:detail_all_projects")
+            else:
+                policy.enforce(context, "cluster:get_all_all_projects",
+                               action="cluster:get_all_all_projects")
+            # TODO(flwang): Instead of asking an extra 'all_project's
+            # parameter, currently the design is allowing admin user to list
+            # all clusters from all projects. But the all_tenants is one of
+            # the condition to do project filter in DB API. And it's also used
+            # by periodic tasks. So the could be removed in the future and
+            # a new parameter 'project_id' would be added so that admin user
+            # can list clusters for a particular project.
+            context.all_tenants = True
+
         limit = api_utils.validate_limit(limit)
         sort_dir = api_utils.validate_sort_dir(sort_dir)
 
@@ -349,6 +385,18 @@ class ClustersController(base.Controller):
         :param cluster_ident: UUID or logical name of the Cluster.
         """
         context = pecan.request.context
+        if context.is_admin:
+            policy.enforce(context, "cluster:get_one_all_projects",
+                           action="cluster:get_one_all_projects")
+            # TODO(flwang): Instead of asking an extra 'all_project's
+            # parameter, currently the design is allowing admin user to list
+            # all clusters from all projects. But the all_tenants is one of
+            # the condition to do project filter in DB API. And it's also used
+            # by periodic tasks. So the could be removed in the future and
+            # a new parameter 'project_id' would be added so that admin user
+            # can list clusters for a particular project.
+            context.all_tenants = True
+
         cluster = api_utils.get_resource('Cluster', cluster_ident)
         policy.enforce(context, 'cluster:get', cluster.as_dict(),
                        action='cluster:get')
@@ -403,6 +451,19 @@ class ClustersController(base.Controller):
         if cluster.docker_volume_size == wtypes.Unset:
             cluster.docker_volume_size = cluster_template.docker_volume_size
 
+        # If labels is not present, use cluster_template value
+        if cluster.labels == wtypes.Unset:
+            cluster.labels = cluster_template.labels
+
+        # If master_flavor_id is not present, use cluster_template value
+        if (cluster.master_flavor_id == wtypes.Unset or
+                not cluster.master_flavor_id):
+            cluster.master_flavor_id = cluster_template.master_flavor_id
+
+        # If flavor_id is not present, use cluster_template value
+        if cluster.flavor_id == wtypes.Unset or not cluster.flavor_id:
+            cluster.flavor_id = cluster_template.flavor_id
+
         cluster_dict = cluster.as_dict()
 
         attr_validator.validate_os_resources(context,
