@@ -17,7 +17,10 @@ import decorator
 
 import pecan
 
+from keystoneauth1 import exceptions as ka_exception
+
 from magnum.api import utils as api_utils
+from magnum.common import clients
 from magnum.common import exception
 import magnum.conf
 from magnum.drivers.common import driver
@@ -44,6 +47,39 @@ def enforce_cluster_type_supported():
     return wrapper
 
 
+def enforce_cluster_volume_storage_size():
+    @decorator.decorator
+    def wrapper(func, *args, **kwargs):
+        cluster = args[1]
+        cluster_template = objects.ClusterTemplate.get_by_uuid(
+            pecan.request.context, cluster.cluster_template_id)
+        _enforce_volume_storage_size(
+            cluster_template.as_dict(), cluster.as_dict())
+        return func(*args, **kwargs)
+
+    return wrapper
+
+
+def enforce_valid_project_id_on_create():
+    @decorator.decorator
+    def wrapper(func, *args, **kwargs):
+        quota = args[1]
+        _validate_project_id(quota.project_id)
+        return func(*args, **kwargs)
+
+    return wrapper
+
+
+def _validate_project_id(project_id):
+    try:
+        context = pecan.request.context
+        osc = clients.OpenStackClients(context)
+        osc.keystone().domain_admin_client.projects.get(project_id)
+    except ka_exception.http.NotFound:
+        raise exception.ProjectNotFound(name='project_id',
+                                        id=project_id)
+
+
 def enforce_network_driver_types_create():
     @decorator.decorator
     def wrapper(func, *args, **kwargs):
@@ -110,7 +146,7 @@ def enforce_volume_storage_size_create():
     @decorator.decorator
     def wrapper(func, *args, **kwargs):
         cluster_template = args[1]
-        _enforce_volume_storage_size(cluster_template.as_dict())
+        _enforce_volume_storage_size(cluster_template.as_dict(), {})
         return func(*args, **kwargs)
 
     return wrapper
@@ -141,10 +177,11 @@ def _enforce_volume_driver_types(cluster_template):
     validator.validate_volume_driver(cluster_template['volume_driver'])
 
 
-def _enforce_volume_storage_size(cluster_template):
-    if not cluster_template.get('docker_volume_size'):
+def _enforce_volume_storage_size(cluster_template, cluster):
+    volume_size = cluster.get('docker_volume_size') \
+        or cluster_template.get('docker_volume_size')
+    if not volume_size:
         return
-    volume_size = cluster_template.get('docker_volume_size')
     storage_driver = cluster_template.get('docker_storage_driver')
     if storage_driver == 'devicemapper':
         if volume_size < 3:
@@ -169,7 +206,7 @@ class Validator(object):
     def get_coe_validator(cls, coe):
         if coe == 'kubernetes':
             return K8sValidator()
-        elif coe == 'swarm':
+        elif coe == 'swarm' or coe == 'swarm-mode':
             return SwarmValidator()
         elif coe == 'mesos':
             return MesosValidator()
