@@ -74,13 +74,19 @@ class K8sFedoraTemplateDefinition(k8s_template_def.K8sTemplateDefinition):
 
         # set docker_volume_type
         # use the configuration default if None provided
-        docker_volume_type = cluster_template.labels.get(
+        docker_volume_type = cluster.labels.get(
             'docker_volume_type', CONF.cinder.default_docker_volume_type)
         extra_params['docker_volume_type'] = docker_volume_type
 
-        kube_tag = cluster_template.labels.get('kube_tag')
-        if kube_tag:
-            extra_params['kube_tag'] = kube_tag
+        extra_params['nodes_affinity_policy'] = \
+            CONF.cluster.nodes_affinity_policy
+
+        label_list = ['kube_tag', 'container_infra_prefix',
+                      'availability_zone']
+        for label in label_list:
+            label_value = cluster.labels.get(label)
+            if label_value:
+                extra_params[label] = label_value
 
         return super(K8sFedoraTemplateDefinition,
                      self).get_params(context, cluster_template, cluster,
