@@ -20,6 +20,7 @@ import six
 
 from magnum.common import clients
 from magnum.common import exception
+from magnum.common import utils
 import magnum.conf
 
 from requests import exceptions as req_exceptions
@@ -244,6 +245,8 @@ class BaseTemplateDefinition(TemplateDefinition):
         extra_params['trustee_user_id'] = cluster.trustee_user_id
         extra_params['trustee_username'] = cluster.trustee_username
         extra_params['trustee_password'] = cluster.trustee_password
+        extra_params['verify_ca'] = CONF.drivers.verify_ca
+        extra_params['openstack_ca'] = utils.get_openstack_ca()
 
         # Only pass trust ID into the template if allowed by the config file
         if CONF.trust.cluster_user_trust:
