@@ -56,6 +56,8 @@ class TestClusterConductorWithMesos(base.TestCase):
             'uuid': '5d12f6fd-a196-4bf0-ae4c-1f639a523a52',
             'cluster_template_id': 'xx-xx-xx-xx',
             'keypair': 'keypair_id',
+            'master_flavor_id': 'master_flavor_id',
+            'flavor_id': 'flavor_id',
             'name': 'cluster1',
             'stack_id': 'xx-xx-xx-xx',
             'api_address': '172.17.2.3',
@@ -66,9 +68,16 @@ class TestClusterConductorWithMesos(base.TestCase):
             'trustee_password': 'fake_trustee_password',
             'trustee_user_id': '7b489f04-b458-4541-8179-6a48a553e656',
             'trust_id': 'bd11efc5-d4e2-4dac-bbce-25e348ddf7de',
+            'labels': {'rexray_preempt': 'False',
+                       'mesos_slave_isolation':
+                       'docker/runtime,filesystem/linux',
+                       'mesos_slave_image_providers': 'docker',
+                       'mesos_slave_executor_env_variables': '{}',
+                       'mesos_slave_work_dir': '/tmp/mesos/slave'
+                       },
         }
         self.context.user_name = 'mesos_user'
-        self.context.tenant = 'admin'
+        self.context.project_id = 'admin'
         self.context.domain_name = 'domainname'
         osc_patcher = mock.patch('magnum.common.clients.OpenStackClients')
         self.mock_osc_class = osc_patcher.start()
@@ -129,7 +138,9 @@ class TestClusterConductorWithMesos(base.TestCase):
             'mesos_slave_executor_env_variables': '{}',
             'mesos_slave_isolation': 'docker/runtime,filesystem/linux',
             'mesos_slave_work_dir': '/tmp/mesos/slave',
-            'mesos_slave_image_providers': 'docker'
+            'mesos_slave_image_providers': 'docker',
+            'verify_ca': True,
+            'openstack_ca': '',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -182,7 +193,11 @@ class TestClusterConductorWithMesos(base.TestCase):
             'mesos_slave_isolation': 'docker/runtime,filesystem/linux',
             'mesos_slave_executor_env_variables': '{}',
             'mesos_slave_work_dir': '/tmp/mesos/slave',
-            'mesos_slave_image_providers': 'docker'
+            'mesos_slave_image_providers': 'docker',
+            'master_flavor': 'master_flavor_id',
+            'verify_ca': True,
+            'slave_flavor': 'flavor_id',
+            'openstack_ca': '',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -239,7 +254,9 @@ class TestClusterConductorWithMesos(base.TestCase):
             'mesos_slave_executor_env_variables': '{}',
             'mesos_slave_isolation': 'docker/runtime,filesystem/linux',
             'mesos_slave_work_dir': '/tmp/mesos/slave',
-            'mesos_slave_image_providers': 'docker'
+            'mesos_slave_image_providers': 'docker',
+            'verify_ca': True,
+            'openstack_ca': '',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -297,7 +314,9 @@ class TestClusterConductorWithMesos(base.TestCase):
             'mesos_slave_executor_env_variables': '{}',
             'mesos_slave_isolation': 'docker/runtime,filesystem/linux',
             'mesos_slave_work_dir': '/tmp/mesos/slave',
-            'mesos_slave_image_providers': 'docker'
+            'mesos_slave_image_providers': 'docker',
+            'verify_ca': True,
+            'openstack_ca': '',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
