@@ -53,7 +53,8 @@ class TestClusterConductorWithSwarm(base.TestCase):
                        'flannel_network_subnetlen': '26',
                        'flannel_backend': 'vxlan',
                        'rexray_preempt': 'False',
-                       'swarm_strategy': 'spread'},
+                       'swarm_strategy': 'spread',
+                       'availability_zone': 'az_1'},
             'master_lb_enabled': False,
             'volume_driver': 'rexray'
         }
@@ -62,7 +63,9 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'uuid': '5d12f6fd-a196-4bf0-ae4c-1f639a523a52',
             'cluster_template_id': 'xx-xx-xx-xx',
             'keypair': 'keypair_id',
+            'flavor_id': 'flavor_id',
             'docker_volume_size': 20,
+            'master_flavor_id': 'master_flavor_id',
             'name': 'cluster1',
             'stack_id': 'xx-xx-xx-xx',
             'api_address': '172.17.2.3',
@@ -74,6 +77,13 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'trustee_password': 'fake_trustee_password',
             'trustee_user_id': '7b489f04-b458-4541-8179-6a48a553e656',
             'trust_id': 'bd11efc5-d4e2-4dac-bbce-25e348ddf7de',
+            'labels': {'docker_volume_type': 'lvmdriver-1',
+                       'flannel_network_cidr': '10.101.0.0/16',
+                       'flannel_network_subnetlen': '26',
+                       'flannel_backend': 'vxlan',
+                       'rexray_preempt': 'False',
+                       'swarm_strategy': 'spread',
+                       'availability_zone': 'az_1'},
             'coe_version': 'fake-version'
         }
 
@@ -153,7 +163,10 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'swarm_strategy': u'spread',
             'volume_driver': 'rexray',
             'rexray_preempt': 'False',
-            'docker_volume_type': 'lvmdriver-1'
+            'docker_volume_type': 'lvmdriver-1',
+            'verify_ca': True,
+            'openstack_ca': '',
+            'nodes_affinity_policy': 'soft-anti-affinity'
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -229,7 +242,10 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'swarm_strategy': u'spread',
             'volume_driver': 'rexray',
             'rexray_preempt': 'False',
-            'docker_volume_type': 'lvmdriver-1'
+            'docker_volume_type': 'lvmdriver-1',
+            'verify_ca': True,
+            'openstack_ca': '',
+            'nodes_affinity_policy': 'soft-anti-affinity'
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -252,7 +268,7 @@ class TestClusterConductorWithSwarm(base.TestCase):
                         'https_proxy', 'no_proxy', 'network_driver',
                         'master_flavor_id', 'docker_storage_driver',
                         'volume_driver', 'rexray_preempt', 'fixed_subnet',
-                        'docker_volume_type']
+                        'docker_volume_type', 'availablity_zone']
         for key in not_required:
             self.cluster_template_dict[key] = None
         self.cluster_dict['discovery_url'] = 'https://discovery.etcd.io/test'
@@ -298,6 +314,11 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'rexray_preempt': 'False',
             'docker_volume_type': 'lvmdriver-1',
             'docker_volume_size': 20,
+            'master_flavor': 'master_flavor_id',
+            'verify_ca': True,
+            'node_flavor': 'flavor_id',
+            'openstack_ca': '',
+            'nodes_affinity_policy': 'soft-anti-affinity'
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -367,7 +388,10 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'swarm_strategy': u'spread',
             'volume_driver': 'rexray',
             'rexray_preempt': 'False',
-            'docker_volume_type': 'lvmdriver-1'
+            'docker_volume_type': 'lvmdriver-1',
+            'verify_ca': True,
+            'openstack_ca': '',
+            'nodes_affinity_policy': 'soft-anti-affinity'
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -438,7 +462,10 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'swarm_strategy': u'spread',
             'volume_driver': 'rexray',
             'rexray_preempt': 'False',
-            'docker_volume_type': 'lvmdriver-1'
+            'docker_volume_type': 'lvmdriver-1',
+            'verify_ca': True,
+            'openstack_ca': '',
+            'nodes_affinity_policy': 'soft-anti-affinity'
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
