@@ -353,10 +353,10 @@ class TestObject(test_base.TestCase, _TestObject):
 # object (fields and remotable methods). If either the version or hash
 # change, the static tree needs to be updated.
 # For more information on object version testing, read
-# http://docs.openstack.org/developer/magnum/objects.html
+# https://docs.openstack.org/magnum/latest/contributor/objects.html
 object_data = {
-    'Cluster': '1.14-281c582b16291c4f0666371e53975a5c',
-    'ClusterTemplate': '1.17-f1ce5212b46506360b41ab5cb7658af4',
+    'Cluster': '1.17-c32c07425ab0042c7370bef2902b4d21',
+    'ClusterTemplate': '1.18-7fa94f4fdd027acfb4f022f202afdfb5',
     'Certificate': '1.1-1924dc077daa844f0f9076332ef96815',
     'MyObj': '1.0-34c4b1aadefd177b13f9a2f894cc23cd',
     'X509KeyPair': '1.2-d81950af36c59a71365e33ce539d24f9',
@@ -380,8 +380,8 @@ class TestObjectVersions(test_base.TestCase):
                          "changed. Make sure the versions of the objects has "
                          "been bumped, and update the hashes in the static "
                          "fingerprints tree (object_data). For more "
-                         "information, read http://docs.openstack.org/"
-                         "developer/magnum/objects.html.")
+                         "information, read https://docs.openstack.org/"
+                         "magnum/latest/contributor/objects.html")
 
 
 class TestObjectSerializer(test_base.TestCase):
